package com.example.cookbook.controller;


import com.example.cookbook.model.Recept;
import com.example.cookbook.model.Slika;
import com.example.cookbook.model.Sostojka;
import com.example.cookbook.model.exception.ReceptNeEPronajdenException;
import com.example.cookbook.service.ReceptService;
import com.example.cookbook.service.SlikiService;
import com.example.cookbook.service.SostojkiService;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;

import java.sql.SQLException;
import java.util.List;

@Controller
public class HomeController {

    private final ReceptService receptService;
    private final SlikiService slikiService;

    private final SostojkiService sostojkiService;

    public HomeController(ReceptService receptService, SlikiService slikiService, SostojkiService sostojkiService) {

        this.receptService = receptService;
        this.slikiService = slikiService;
        this.sostojkiService = sostojkiService;
    }

    @GetMapping({"/", "/recepti"})
    public String getHomePage(Model model){

        List<Recept> recepti = null;
        try {
            recepti = receptService.listAll();
        } catch (SQLException e) {
            return "redirect:/error-page/SQL%20Exception";
        }
        model.addAttribute("recepti", recepti);
        return "home";
    }

    @GetMapping("/recept/{id}")
    public String getReceptPage(@PathVariable Long id, Model model){

        Recept recept = null;
        List<Slika> sliki;
        List<Sostojka> sostojki;
        try {
            recept = receptService.findById(id);
            sliki = slikiService.findAllPicById(id);
            sostojki = sostojkiService.findAllById(id);
        } catch (SQLException e) {
            return "redirect:/error-page/SQL%20Exception";
        }catch (ReceptNeEPronajdenException e){
            return "redirect:/error-page/" + e.getMessage();
        }
        model.addAttribute("recept", recept);
        model.addAttribute("sliki", sliki);
        model.addAttribute("sostojki", sostojki);
        return "recept";
    }


    @GetMapping("/error-page/{error}")
    public String getErrorPage(@PathVariable(required = false) String error, Model model){

        if (error != null){
            model.addAttribute("error", error);
        }
        return "error-page";
    }
}
